package com.srs.staff.service;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.IService;
import com.srs.staff.domain.SrsStaffOneStopCommunityActivities;

/**
 * 一站式社区模块-社区活动Service接口
 *
 * @author chc
 * @date 2024-07-16
 */
public interface ISrsStaffOneStopCommunityActivitiesService extends IService<SrsStaffOneStopCommunityActivities> {
    /**
     * 查询一站式社区模块-社区活动
     *
     * @param activityId 一站式社区模块-社区活动主键
     * @return 一站式社区模块-社区活动
     */
    public SrsStaffOneStopCommunityActivities selectSrsStaffOneStopCommunityActivitiesByActivityId(Long activityId);

    /**
     * 查询一站式社区模块-社区活动列表
     *
     * @param srsStaffOneStopCommunityActivities 一站式社区模块-社区活动
     * @return 一站式社区模块-社区活动集合
     */
    List<SrsStaffOneStopCommunityActivities> selectSrsStaffOneStopCommunityActivitiesList(SrsStaffOneStopCommunityActivities srsStaffOneStopCommunityActivities);

    /**
     * 新增一站式社区模块-社区活动
     *
     * @param srsStaffOneStopCommunityActivities 一站式社区模块-社区活动
     * @return 结果
     */
    int insertSrsStaffOneStopCommunityActivities(SrsStaffOneStopCommunityActivities srsStaffOneStopCommunityActivities);

    /**
     * 修改一站式社区模块-社区活动
     *
     * @param srsStaffOneStopCommunityActivities 一站式社区模块-社区活动
     * @return 结果
     */
    int updateSrsStaffOneStopCommunityActivities(SrsStaffOneStopCommunityActivities srsStaffOneStopCommunityActivities);

    /**
     * 批量删除一站式社区模块-社区活动
     *
     * @param activityIds 需要删除的一站式社区模块-社区活动主键集合
     * @return 结果
     */
    int deleteSrsStaffOneStopCommunityActivitiesByActivityIds(Long[] activityIds);

    /**
     * 删除一站式社区模块-社区活动信息
     *
     * @param activityId 一站式社区模块-社区活动主键
     * @return 结果
     */
    int deleteSrsStaffOneStopCommunityActivitiesByActivityId(Long activityId);
}
